@@ -57,11 +57,13 @@
 
 /////////////////////// Local includes
 #include "Application.hpp"
+#include "ProgramWindow.hpp"
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
 #include "gui/MsRunDataSetTableView.hpp"
 #include "gui/MsRunDataSetTableViewItem.hpp"
 #include "gui/MsRunDataSetTableViewModel.hpp"
 #include "gui/MsRunDataSetTableViewProxyModel.hpp"
+#include "../nongui/globals.hpp"
 
 
 namespace msxps
@@ -232,6 +234,12 @@ Application::getUserConfigSettingsFilePath()
 }
 
 
+void
+Application::setProgramWindow(ProgramWindow *program_window_p)
+{
+  mp_programWindow = program_window_p;
+}
+
 } // namespace minexpert
 
 } // namespace msxps
