@@ -53,18 +53,14 @@ namespace msxps
 namespace minexpert
 {
 
+class ProgramWindow;
+
 class Application : public QApplication
 {
   Q_OBJECT
 
-  private:
-  QString m_moduleName = "minexpert2";
-
-  // The splash screen, that we'll remove automatically after
-  // 2 seconds.
-  QSplashScreen *mpa_splash;
-  QString m_userConfigSettingsDirPath;
-  QString m_userConfigSettingsFilePath;
+  ////////////////////////////// public //////////////////////////// /
+  ////////////////////////////// public //////////////////////////////
 
   public:
   Application(int &argc, char **argv, const QString &moduleName);
@@ -75,15 +71,29 @@ class Application : public QApplication
   QString m_description = QString(
     "mineXpert2: a program to view and analyze mass spectrometric data");
 
+  void setProgramWindow(ProgramWindow *program_window_p);
+
   public slots:
   void setDescription(QString &desc);
   QString description();
 
   void destroySplash();
 
-  public:
   QString getUserConfigSettingsDirPath();
   QString getUserConfigSettingsFilePath();
+
+  ////////////////////////////// private //////////////////////////// /
+  ////////////////////////////// private //////////////////////////////
+
+  private:
+  QString m_moduleName            = "minexpert2";
+  ProgramWindow *mp_programWindow = nullptr;
+
+  // The splash screen, that we'll remove automatically after
+  // 2 seconds.
+  QSplashScreen *mpa_splash;
+  QString m_userConfigSettingsDirPath;
+  QString m_userConfigSettingsFilePath;
 };
 
 } // namespace minexpert
