@@ -226,7 +226,8 @@ BasePlotCompositeWidget::createMainMenu()
   QAction *reset_plot_ranges_history_p =
     new QAction("&Reset plot ranges history", dynamic_cast<QObject *>(this));
   reset_plot_ranges_history_p->setStatusTip(
-    "Empty the list of plot ranges in the history (reset the backspace feature)");
+    "Empty the list of plot ranges in the history (reset the backspace "
+    "feature)");
   reset_plot_ranges_history_p->setShortcut(QKeySequence("Ctrl+R, H"));
 
   connect(reset_plot_ranges_history_p,
@@ -457,7 +458,8 @@ BasePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
   // Display the position point in the status text.
 
   m_ui.statusLineEdit->setText(
-    QString("(%1,%2)").arg(pointf.x(), 0, 'f', 3).arg(pointf.y(), 0, 'f', 3));
+    QString("(%1,%2)").arg(pointf.x(), 0, 'f', 5).arg(pointf.y(), 0, 'f', 5));
+
   // qDebug() << "point: (" << pointf.x() << "," << pointf.y() << ")";
 }
 
@@ -530,14 +532,16 @@ BasePlotCompositeWidget::xAxisMeasurement(
 
   // We always want the X delta.
   context.m_selectionPolygon.rangeX(start, end);
-  text += QString(" -- xDelta: %1").arg(end - start, 0, 'f', 3);
+  double delta = abs(end - start);
+  int decimals = pappso::Utils::zeroDecimalsInValue(delta) + 3;
+  text += QString(" -- xDelta: %1").arg(end - start, 0, 'f', decimals);
 
   // We want the Y delta only if the polygon is 2D.
   if(context.m_selectionPolygon.is2D() && with_delta)
     {
       // qDebug() << "Selection polygon is 2D";
       context.m_selectionPolygon.rangeY(start, end);
-      text += QString(" -- yDelta: %1").arg(end - start, 0, 'f', 3);
+      text += QString(" -- yDelta: %1").arg(end - start, 0, 'f', 2);
     }
 
   m_ui.statusLineEdit->setText(text);
@@ -1027,17 +1031,17 @@ BasePlotCompositeWidget::getMzIntegrationParams(
         }
       else
         {
-          // qDebug().noquote() << "Got the most recent mz integration params:"
-          //<< most_recent_mz_integration_params_p->toString();
+          //qDebug().noquote() << "Got the most recent mz integration params:"
+                             //<< most_recent_mz_integration_params_p->toString();
 
           mz_integration_params = *most_recent_mz_integration_params_p;
         }
     }
-  else
-    {
-      // qDebug().noquote() << "Got the default mz integration params:"
-      //<< mz_integration_params.toString();
-    }
+  //else
+    //{
+      //qDebug().noquote() << "Got the default mz integration params:"
+                         //<< mz_integration_params.toString();
+    //}
 
   if(!mz_integration_params.isValid())
     qFatal("Cannot be possible not to have valid mz integration parameters.");
@@ -1055,8 +1059,8 @@ BasePlotCompositeWidget::filter(const QString filter_name,
   const ProcessingFlow &processing_flow =
     getProcessingFlowForPlottable(plottable_p);
 
-  //qDebug() << "The source plottable:" << plottable_p;
-  //qDebug() << "The processing flow:" << &processing_flow;
+  // qDebug() << "The source plottable:" << plottable_p;
+  // qDebug() << "The processing flow:" << &processing_flow;
 
   return processing_flow.filter(filter_name);
 }
@@ -1065,8 +1069,6 @@ BasePlotCompositeWidget::filter(const QString filter_name,
 void
 BasePlotCompositeWidget::showMzIntegrationParamsDlg()
 {
-  // qDebug();
-
   // First we get the source plottable that might be of interest to the user.
 
   QCPAbstractPlottable *source_plottable_p =
@@ -1089,8 +1091,8 @@ BasePlotCompositeWidget::showMzIntegrationParamsDlg()
   pappso::MzIntegrationParams mz_integration_params =
     getMzIntegrationParams(source_plottable_p);
 
-  // qDebug().noquote() << "Found mz integration params:"
-  //<< mz_integration_params.toString();
+  qDebug().noquote() << "Found mz integration params:"
+                     << mz_integration_params.toString();
 
   if(mp_mzIntegrationParamsDlg == nullptr)
     {
@@ -1373,14 +1375,14 @@ BasePlotCompositeWidget::craftAnalysisStanza(
           if(curChar == 'b')
             {
               stanza +=
-                QString("%1").arg(context.m_xRegionRangeStart, 0, 'f', 3);
+                QString("%1").arg(context.m_xRegionRangeStart, 0, 'f', 4);
 
               prevChar = ' ';
               continue;
             }
           if(curChar == 'e')
             {
-              stanza += QString("%1").arg(context.m_xRegionRangeEnd, 0, 'f', 3);
+              stanza += QString("%1").arg(context.m_xRegionRangeEnd, 0, 'f', 4);
 
               prevChar = ' ';
               continue;
