@@ -979,8 +979,8 @@ BasePlotWnd::integrateToTicIntensity(
   if(!qualified_mass_spectra_count)
     return;
 
-  qDebug() << "The number of remaining mass spectra:"
-           << qualified_mass_spectra_count;
+  //qDebug() << "The number of remaining mass spectra:"
+           //<< qualified_mass_spectra_count;
 
   // Now start the actual integration work.
 
@@ -1504,17 +1504,17 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   if(!integration)
     qFatal("Programming error.");
 
-  qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
-           << "-" << range_pair.second;
+  //qDebug() << "Filling-in mass spectra for RT range: " << range_pair.first
+           //<< "-" << range_pair.second;
 
-  std::size_t added_rt_mass_spectra =
+  //std::size_t added_rt_mass_spectra =
     ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
       ->addDataSetQualMassSpectraInsideDtRtRange(range_pair.first,
                                                  range_pair.second,
                                                  *qualified_mass_spectra_sp,
                                                  pappso::DataKind::rt);
 
-  qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
+  //qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
 
   // Now see if we can remove some mass spectra on the basis of DT values.
 
@@ -1527,20 +1527,20 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   // the mass spectral acquisitions involved ion mobility.
   if(integration)
     {
-      qDebug()
-        << "Detected DT integration, removing mass spectra outside DT range: "
-        << range_pair.first << "-" << range_pair.second;
+      //qDebug()
+        //<< "Detected DT integration, removing mass spectra outside DT range: "
+        //<< range_pair.first << "-" << range_pair.second;
 
-      std::size_t removed_mass_spectra =
-        ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
-          ->removeDataSetQualMassSpectraOutsideDtRtRange(
-            range_pair.first,
-            range_pair.second,
-            *qualified_mass_spectra_sp,
-            pappso::DataKind::dt);
+      //std::size_t removed_mass_spectra =
+        //ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+          //->removeDataSetQualMassSpectraOutsideDtRtRange(
+            //range_pair.first,
+            //range_pair.second,
+            //*qualified_mass_spectra_sp,
+            //pappso::DataKind::dt);
 
-      qDebug() << "Number of mass spectra removed on the basis of DT:"
-               << removed_mass_spectra;
+      //qDebug() << "Number of mass spectra removed on the basis of DT:"
+               //<< removed_mass_spectra;
     }
 
   // At this point we need to really check which of the remaining spectra are
