@@ -51,10 +51,7 @@
 #include "BaseTracePlotCompositeWidget.hpp"
 #include "BaseTracePlotWnd.hpp"
 #include "ColorSelector.hpp"
-#include "MsFragmentationSpecDlg.hpp"
-#include "MzIntegrationParamsDlg.hpp"
 #include "ProgramWindow.hpp"
-#include "LabelledDoubleSpinBoxAction.hpp"
 #include "LabelledNumberLineEditAction.hpp"
 
 
@@ -750,7 +747,7 @@ void
 BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
 {
-  // qDebug();
+   //qDebug() << "ENTER with base plot context:" << context.toString();
 
   // Call the base class that will fill-in various generic data, like the
   // file/sample name, the x and y ranges...
@@ -806,17 +803,21 @@ BaseTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
             mp_plotWidget->xAxis->coordToPixel(context.m_currentDragPoint.y()));
 
           QMouseEvent *mouse_event_p = new QMouseEvent(QEvent::MouseButtonPress,
+                                                       mouseCursorPos,
                                                        mouseCursorPos,
                                                        Qt::LeftButton,
                                                        Qt::LeftButton,
                                                        Qt::NoModifier);
+
           QCoreApplication::sendEvent(QWidget::focusWidget(), mouse_event_p);
 
           mouse_event_p = new QMouseEvent(QEvent::MouseButtonRelease,
+                                          mouseCursorPos,
                                           mouseCursorPos,
                                           Qt::LeftButton,
                                           Qt::LeftButton,
                                           Qt::NoModifier);
+
           QCoreApplication::sendEvent(QWidget::focusWidget(), mouse_event_p);
         }
 
