@@ -112,7 +112,7 @@ BaseTracePlotWnd::getNoiseSampleStats(std::size_t &point_count,
   // between, the values might be 0).
 
   QString trace_as_string = mpa_noiseSampleTrace->toString();
-  qDebug().noquote() << "Trace as string\n" << trace_as_string;
+  //qDebug().noquote() << "Trace as string\n" << trace_as_string;
 
   std::vector<double> intensities = mpa_noiseSampleTrace->yValues();
 
@@ -150,9 +150,9 @@ BaseTracePlotWnd::getNoiseSampleStats(std::size_t &point_count,
   variance /= mean;
   std_dev = sqrt(variance);
 
-  qDebug() << "The noise point count:" << point_count
-           << " -- the noise mean:" << mean
-           << " -- the noise std deviation: " << std_dev;
+  //qDebug() << "The noise point count:" << point_count
+           //<< " -- the noise mean:" << mean
+           //<< " -- the noise std deviation: " << std_dev;
 
   return true;
 }
