@@ -41,6 +41,7 @@
 
 
 /////////////////////// pappsomspp includes
+#include <pappsomspp/trace/trace.h>
 
 
 /////////////////////// Local includes
@@ -70,6 +71,12 @@ class BaseTracePlotWnd : public BasePlotWnd
                    const QString &description = QString());
   virtual ~BaseTracePlotWnd();
 
+  void setNoiseSampleTrace(const pappso::Trace &trace);
+  void resetNoiseSampleTrace();
+  bool
+  getNoiseSampleStats(std::size_t &point_count, double &mean, double &std_dev);
+
+
   // This function first checks if there are receiving plots (pinned-down plot
   // widgets) or not.
   virtual void newTrace(const pappso::Trace &trace,
@@ -99,11 +106,12 @@ class BaseTracePlotWnd : public BasePlotWnd
   duplicateTracePlot(const BaseTracePlotCompositeWidget *composite_widget_p);
 
 
-    public slots :
+  public slots:
 
-    signals :
+  signals:
 
-    protected:
+  protected:
+  pappso::Trace *mpa_noiseSampleTrace = nullptr;
 };
 
 
