@@ -175,7 +175,7 @@ void
 DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
 {
-   qDebug().noquote() << "context:" << context.toString();
+  // qDebug().noquote() << "context:" << context.toString();
 
   // We are getting that signal from a plot widget that operates as a
   // drift spec / mass spec color map plot widget. By essence, the selected
@@ -188,16 +188,20 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(!context.m_selectionPolygon.is2D())
     {
-      qDebug() << "The selection polygon cannot be mono-dimensional when "
-                  "selecting for integration from color map";
+      // qDebug() << "The selection polygon cannot be mono-dimensional when "
+      //"selecting for integration from color map";
       return;
     }
   else
     {
       if(context.m_selectionPolygon.isRectangle())
-        qDebug() << "The selection polygon is rectangle.";
+        {
+          // qDebug() << "The selection polygon is rectangle.";
+        }
       else
-        qDebug() << "The selection polygon is oblique (skewed).";
+        {
+          // qDebug() << "The selection polygon is oblique (skewed).";
+        }
     }
 
   // Sanity check.
@@ -211,7 +215,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
 
-  qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
+  //qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
   if(x_range_start < 0 && x_range_end < 0)
     return;
@@ -221,7 +225,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
 
-  qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
+  //qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
   if(y_range_start < 0 && y_range_end < 0)
     return;
@@ -262,13 +266,13 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   ProcessingFlow local_processing_flow =
     getProcessingFlowForPlottable(plottable_p);
 
-  // qDebug().noquote() << "Processing flow for graph:"
-  //<< local_processing_flow.toString();
+  //qDebug().noquote() << "Processing flow for graph:"
+                     //<< local_processing_flow.toString();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
 
-  // qDebug() << ms_run_data_set_csp->getMsRunDataSetStats().toString();
+  //qDebug() << ms_run_data_set_csp->getMsRunDataSetStats().toString();
 
   // Create a processing step to document the specifics of this new integration.
 
@@ -311,9 +315,13 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       ->yAxisDataKind();
 
   if(x_axis_data_kind == pappso::DataKind::dt)
+  { 
     qDebug() << "X axis: dt";
+  }
   else if(x_axis_data_kind == pappso::DataKind::mz)
+  { 
     qDebug() << "X axis: mz";
+  }
 
   if(x_axis_data_kind == pappso::DataKind::dt &&
      y_axis_data_kind != pappso::DataKind::mz)
@@ -329,8 +337,8 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // The colormap can have its axes transposed, so we need to ensure that we
   // document the axis/data-kind relation properly. Note that we want the
   // processing step to be documented according to the alpha numerical ordering.
-  // So, if we are working in a DT_RT colormap, then, x axis needs to be DT and
-  // y axis needs to be RT.
+  // So, if we are working in a DT_DT colormap, then, x axis needs to be DT and
+  // y axis needs to be DT.
 
   // Make a local copy of the selection polygon because we might need to
   // transpose it.
@@ -339,15 +347,15 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(x_axis_data_kind == pappso::DataKind::mz)
     {
-      // We have to transpose the selection rectangle so that x:MZ and y:RT.
+      // We have to transpose the selection rectangle so that x:MZ and y:DT.
       local_selection_polygon = local_selection_polygon.transpose();
     }
   // else
-  // No need to tranpose, we deal with data in the right x:MZ y:RT.
+  // No need to tranpose, we deal with data in the right x:MZ y:DT.
 
-   qDebug() << "The selection polygon:" << local_selection_polygon.toString();
+  //qDebug() << "The selection polygon:" << local_selection_polygon.toString();
 
-  // Now we know we have the right selection polygon for x:MZ and y:RT.
+  // Now we know we have the right selection polygon for x:MZ and y:DT.
 
   processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
   processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
@@ -369,7 +377,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(m_ui.integrateToRtPushButton->isChecked())
     {
-       qDebug() << "Integrating to XIC chromatogram.";
+      //qDebug() << "Integrating to XIC chromatogram.";
 
       // We need to set two specs to the step.
 
@@ -382,7 +390,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtRtPushButton->isChecked())
     {
-       qDebug() << "Integrating to dt / rt color map.";
+      //qDebug() << "Integrating to dt / rt color map.";
 
       processing_step_p->setDestProcessingType("DT_RT");
 
@@ -398,19 +406,19 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       if(m_ui.integrateToMzPushButton->isChecked())
         {
-           qDebug() << "Integrating to mass spectrum.";
+          //qDebug() << "Integrating to mass spectrum.";
 
           processing_step_p->setDestProcessingType("MZ");
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
-           qDebug() << "Integrating to rt / m/z color map.";
+          //qDebug() << "Integrating to rt / m/z color map.";
 
           processing_step_p->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
-           qDebug() << "Integrating to dt / m/z color map.";
+          //qDebug() << "Integrating to dt / m/z color map.";
 
           processing_step_p->setDestProcessingType("DT_MZ");
         }
@@ -426,12 +434,18 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
+      //qDebug()
+        //<< "The graph's processing flow has default mz integration params:"
+        //<< mz_integration_params.toString();
+
       // If it is not valid, then try mz integration params from the various
       // steps of the flow. Preferentially the most recent ones.
       if(!mz_integration_params.isValid())
         {
-          // qDebug()
-          //<< "The processing flow's default mz integ params are not valid.";
+          //qDebug()
+            //<< "The processing flow's default mz integ params are not "
+               //"valid. Trying to get the most recent mz integ params "
+               //"from the processing flow. If valid, we may tune them later.";
 
           mz_integration_params =
             *(local_processing_flow.mostRecentMzIntegrationParams());
@@ -442,15 +456,60 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // while it was loaded from file.
       if(!mz_integration_params.isValid())
         {
-          // qDebug() << "The most recent mz integ param are not valid.";
+          //qDebug() << "The most recent mz integ param are not valid. We use "
+                      //"the getMsRunDataSetStats to craft new ones that we may "
+                      //"tune later.";
 
           mz_integration_params =
             ms_run_data_set_csp->craftInitialMzIntegrationParams();
         }
+      else
+        {
+          //qDebug() << "The most recent mz integ params are valid. Use them, "
+                      //"with potential tuning.";
+        }
 
       if(!mz_integration_params.isValid())
         qFatal(
-          "The mz integ params from the ms run data set stats are not valid.");
+          "The mz integ params from the ms run data set stats are not "
+          "valid.");
+
+      // At this point, let's see if we can optimize the integration
+      // computation. Indeed, if we know we have an mz range in the selection
+      // polygon, document that range to lower computing time.
+
+      double mz_range_lower = std::numeric_limits<double>::max();
+      double mz_range_upper = std::numeric_limits<double>::min();
+
+      // We know we have the x axis being the dt while the mz is the y axis.
+
+      bool res = local_selection_polygon.rangeY(mz_range_lower, mz_range_upper);
+
+      if(!res)
+        {
+          qFatal("Failed to get the m/z range out of the selection polygon");
+        }
+
+      // At this point, change the values in the mz_integration_params so
+      // that the min and max values match the range, which will ensure that
+      // the integration is the quickest possible as the bins are created in
+      // this range and not in another one that might be larger (if the
+      // integration comes right from the intial TIC, then the range is the
+      // whole range of the mass data in the dataset.
+
+      mz_integration_params.setSmallestMz(mz_range_lower);
+      mz_integration_params.setGreatestMz(mz_range_upper);
+
+      //qDebug() << "After tuning the mz range, mz integration params:"
+               //<< mz_integration_params.toString();
+
+
+#if 0
+
+      // This is no more true: we do not force a low resolution computation for
+      // the color maps. The mz integration parameters are now entirely
+      // satisfied.
+
 
       // Note that we cannot integrate mass spectra with a high resolution
       // here. We need to reduce the resolution to integer resolution.
@@ -461,20 +520,22 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
           mz_integration_params.setDecimalPlaces(0);
         }
 
-      // We finally have mz integ params that we can set to the processing step
-      // that we are creating to document this current integration.
+#endif
+
+      // We finally have mz integ params that we can set to the processing
+      // step that we are creating to document this current integration.
       processing_step_p->setMzIntegrationParams(mz_integration_params);
 
-      // And nwo add the new processing step to the local copy of the processing
-      // flow, so that we document on top of all the previous steps, also this
-      // last one.
+      // And now add the new processing step to the local copy of the
+      // processing flow, so that we document on top of all the previous
+      // steps, also this last one.
       local_processing_flow.push_back(processing_step_p);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
 
-      // The local processing flow contains all the previous steps and the last
-      // one that documents this current integration.
+      // The local processing flow contains all the previous steps and the
+      // last one that documents this current integration.
 
       if(m_ui.integrateToMzPushButton->isChecked())
         {
@@ -494,7 +555,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtPushButton->isChecked())
     {
-       qDebug() << "Integrating to drift spectrum.";
+      //qDebug() << "Integrating to drift spectrum.";
 
       processing_step_p->setDestProcessingType("DT");
 
@@ -505,7 +566,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToIntPushButton->isChecked())
     {
-       qDebug() << "Integrating to TIC intensity.";
+      //qDebug() << "Integrating to TIC intensity.";
 
       processing_step_p->setDestProcessingType("INT");
 
