@@ -700,19 +700,19 @@ void
 MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::MassSpecTracePlotContext &context)
 {
-   //qDebug().noquote() << "ENTER with massplotcontext:" << context.toString();
+  //qDebug().noquote() << "ENTER with massplotcontext:" << context.toString();
 
   // First call the base class that will fill-in the generic fields if the space
   // char was pressed.
-  BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(context.m_baseContext);
+  BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(context);
 
   // qDebug() << "After filling-in by base class, the stanza is:"
   //<< m_analysisStanza;
 
-  m_plotWidgetPressedKeyCode = context.m_baseContext.m_pressedKeyCode;
+  m_plotWidgetPressedKeyCode = context.m_pressedKeyCode;
 
   // Now handle here the mass specific data, like z, Mr, m/z.
-  if(context.m_baseContext.m_pressedKeyCode == Qt::Key_Space)
+  if(context.m_pressedKeyCode == Qt::Key_Space)
     {
       QCPAbstractPlottable *plottable_p =
         plottableToBeUsedAsIntegrationSource();
@@ -744,14 +744,61 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
 
       QString stanza = craftAnalysisStanza(context);
 
-      // qDebug() << "analysis stanza:" << stanza;
+      //qDebug() << "analysis stanza:" << stanza;
 
       // At this point, the analysis stanza can be effectively recorded.
 
       mp_parentWnd->recordAnalysisStanza(stanza, plottable_p->pen().color());
     }
   // End of
-  // if(context.m_baseContext.m_pressedKeyCode == Qt::Key_Space)
+  // if(context.m_pressedKeyCode == Qt::Key_Space)
+  else if(context.m_pressedKeyCode == Qt::Key_M)
+    {
+      // The M (lowercase) keyboard key triggers copying the m/z value to the
+      // clipboard when a deconvolution was performed.
+
+      QString mz_value_as_string =
+        QString("%1").arg(context.m_lastMr, 0, 'f', 6);
+
+      //qDebug() << "The mz_value_as_string:" << mz_value_as_string;
+
+      QClipboard *clipboard_p = QApplication::clipboard();
+      clipboard_p->setText(mz_value_as_string, QClipboard::Clipboard);
+    }
+  // End of
+  // else if(context.m_pressedKeyCode == Qt::Key_M)
+  else if(context.m_pressedKeyCode == Qt::Key_Z)
+    {
+      // The Z (lowercase) keyboard key triggers copying the z value to the
+      // clipboard when a deconvolution was performed.
+
+      QString z_value_as_string = QString("%1").arg(context.m_lastZ);
+
+      //qDebug() << "The z_value_as_string:" << z_value_as_string;
+
+      QClipboard *clipboard_p = QApplication::clipboard();
+      clipboard_p->setText(z_value_as_string, QClipboard::Clipboard);
+    }
+  // End of
+  // else if(context.m_pressedKeyCode == Qt::Key_Z)
+  else if(context.m_pressedKeyCode == Qt::Key_X)
+    {
+      // The X (lowercase) keyboard key triggers copying the m/z value exactly
+      // as the last cursor position (no deconvolution needs to be performed to
+      // get to the x value (in a mass spectrum trace, the x value is the m/z
+      // value).
+
+      QPointF point = context.m_lastCursorHoveredPoint;
+
+      QString x_value_as_string = QString("%1").arg(point.x(), 0, 'f', 6);
+
+      //qDebug() << "The x_value_as_string:" << x_value_as_string;
+
+      QClipboard *clipboard_p = QApplication::clipboard();
+      clipboard_p->setText(x_value_as_string, QClipboard::Clipboard);
+    }
+  // End of
+  // else if(context.m_pressedKeyCode == Qt::Key_X)
 }
 
 
@@ -788,20 +835,20 @@ MassSpecTracePlotCompositeWidget::plotWidgetMassDeconvolution(
 
   QString new_text =
     QString("[%1--%2] - delta: %3 -- z: %4 - m/z: %5 - Mr: %6")
-      .arg(std::min<double>(context.m_baseContext.m_xRegionRangeStart,
-                            context.m_baseContext.m_xRegionRangeEnd),
+      .arg(std::min<double>(context.m_xRegionRangeStart,
+                            context.m_xRegionRangeEnd),
            0,
            'f',
-           3)
-      .arg(std::max<double>(context.m_baseContext.m_xRegionRangeStart,
-                            context.m_baseContext.m_xRegionRangeEnd),
+           4)
+      .arg(std::max<double>(context.m_xRegionRangeStart,
+                            context.m_xRegionRangeEnd),
            0,
            'f',
-           3)
-      .arg(fabs(context.m_baseContext.m_xDelta), 0, 'f', 3)
+           4)
+      .arg(fabs(context.m_xDelta), 0, 'f', 4)
       .arg(context.m_lastZ)
-      .arg(context.m_lastMz, 0, 'f', 3)
-      .arg(context.m_lastMr);
+      .arg(context.m_lastMz, 0, 'f', 4)
+      .arg(context.m_lastMr, 0, 'f', 3);
 
   m_ui.statusLineEdit->setText(new_text);
 }
@@ -827,7 +874,6 @@ MassSpecTracePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
 
   // qDebug() << "pointf:" << pointf;
 
-
   // At this point we can start doing mass spectrum-specific calculations.
 }
 
@@ -1661,7 +1707,7 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
               else
                 {
                   stanza += QString("%1").arg(
-                    context.m_baseContext.m_lastCursorHoveredPoint.x(),
+                    context.m_lastCursorHoveredPoint.x(),
                     0,
                     'g',
                     6);
@@ -1693,7 +1739,7 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
                     static_cast<pappso::MassSpecTracePlotWidget *>(
                       mp_plotWidget)
                       ->getYatX(
-                        context.m_baseContext.m_lastCursorHoveredPoint.x(),
+                        context.m_lastCursorHoveredPoint.x(),
                         static_cast<QCPGraph *>(plottable_p)),
                     0,
                     'g',
@@ -1706,7 +1752,7 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
           if(curChar == 'x')
             {
               stanza +=
-                QString("%1").arg(context.m_baseContext.m_xDelta, 0, 'g', 6);
+                QString("%1").arg(context.m_xDelta, 0, 'g', 6);
               prevChar = ' ';
               continue;
             }
@@ -1741,7 +1787,7 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
           if(curChar == 'b')
             {
               stanza += QString("%1").arg(
-                context.m_baseContext.m_xRegionRangeStart, 0, 'f', 3);
+                context.m_xRegionRangeStart, 0, 'f', 3);
 
               prevChar = ' ';
               continue;
@@ -1749,7 +1795,7 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
           if(curChar == 'e')
             {
               stanza += QString("%1").arg(
-                context.m_baseContext.m_xRegionRangeEnd, 0, 'f', 3);
+                context.m_xRegionRangeEnd, 0, 'f', 3);
 
               prevChar = ' ';
               continue;
