@@ -190,8 +190,8 @@ MassSpecTracePlotWnd::integrateToMz(
     qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
 {
-  qDebug().noquote() << "Integrating to mz with processing flow:"
-                     << processing_flow.toString();
+  // qDebug().noquote() << "Integrating to mz with processing flow:"
+  //<< processing_flow.toString();
 
   // Get the ms run data set that for the graph we are going to base the
   // integration on.
@@ -200,7 +200,8 @@ MassSpecTracePlotWnd::integrateToMz(
   if(ms_run_data_set_csp == nullptr)
     qFatal("Cannot be that the pointer is nullptr.");
 
-  // FIXME: BEGIN Sanity check that might be removed when the program is stabilized.
+  // FIXME: BEGIN Sanity check that might be removed when the program is
+  // stabilized.
   std::pair<double, double> range_pair;
 
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
@@ -208,15 +209,16 @@ MassSpecTracePlotWnd::integrateToMz(
   if(!integration_rt)
     qFatal("Programming error.");
 
-  qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
-           << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
+  //<< "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  //bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
+  // if(integration_dt)
+  // qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
+  //<< "for y axis: " << range_pair.first << "-" << range_pair.second;
 
-  if(integration_dt)
-    qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-             << "for y axis: " << range_pair.first << "-" << range_pair.second;
-  // FIXME: END Sanity check that might be removed when the program is stabilized.
+  // FIXME: END Sanity check that might be removed when the program is
+  // stabilized.
 
   // What integration parameters are we going to use ? Since we do integrate to
   // a mass spectrum it is compulsory that the most recent step has valid mz
@@ -239,9 +241,9 @@ MassSpecTracePlotWnd::integrateToMz(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  qDebug()
-    << "The number of selected mass spectra on the basis of rough RT/DT values:"
-    << qualified_mass_spectra_count;
+  //qDebug()
+    //<< "The number of selected mass spectra on the basis of rough RT/DT values:"
+    //<< qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -401,7 +403,6 @@ MassSpecTracePlotWnd::finishedIntegratingToMz(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
   QCPAbstractPlottable *parent_plottable_p)
 {
-  qDebug();
 
   // This function is actually a slot that is called when the integration to
   // mz is terminated in a QThread.
