@@ -193,11 +193,11 @@ MsRunDataSetTableViewModel::data(const QModelIndex &index, int role) const
           switch(ms_level_int)
             {
               case 1:
-                return QIcon(":/images/ms-level-1.png");
+                return QIcon(":/images/svg/ms-level-1.svg");
               case 2:
-                return QIcon(":/images/ms-level-2.png");
+                return QIcon(":/images/svg/ms-level-2.svg");
               case 3:
-                return QIcon(":/images/ms-level-3.png");
+                return QIcon(":/images/svg/ms-level-3.svg");
               default:
                 return QVariant();
             }
