@@ -46,6 +46,7 @@
 #include "MsRunDataSetTableViewModel.hpp"
 #include "MsRunDataSetTableViewProxyModel.hpp"
 #include "MsRunDataSetTableViewItem.hpp"
+#include "../nongui/ProcessingStep.hpp"
 
 
 namespace msxps
@@ -141,8 +142,8 @@ MsRunDataSetTableViewProxyModel::parseSizeTString(const QString &text,
     }
 
 
-  // Range of values pattern (xxx - yyy)
-  regexp.setPattern("^\\s*(\\d+)\\s*-\\s*(\\d+)\\s*$");
+  // Range of values pattern (xxx -- yyy)
+  regexp.setPattern("^\\s*(\\d+)\\s*--\\s*(\\d+)\\s*$");
 
   match = regexp.match(text);
 
@@ -461,6 +462,8 @@ std::pair<double, double>
 MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
                                                    double accepted_lower_value)
 {
+  qDebug() << "text:" << text;
+
   // The accepted syntax is like this:
   //
   // xxx
@@ -542,9 +545,10 @@ MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
     }
 
 
-  // Range of values pattern (xxx - yyy)
-  regexp.setPattern("^\\s*" + sci_number + "\\s*-\\s*" + sci_number + "\\s*$");
+  // Range of values pattern (xxx -- yyy)
+  regexp.setPattern("^\\s*" + sci_number + "\\s*--\\s*" + sci_number + "\\s*$");
 
+  qDebug() << "testing range:" << regexp.pattern();
 
   match = regexp.match(text);
 
@@ -563,12 +567,16 @@ MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
       range_pair.second = upper_value_string.toDouble(&ok);
 
       if(!ok || range_pair.second < accepted_lower_value)
-        return std::pair<double, double>(std::numeric_limits<double>::max(),
-                                         std::numeric_limits<double>::min());
+        {
+          qDebug() << "Failed to convert or was below lower.";
+
+          return std::pair<double, double>(std::numeric_limits<double>::max(),
+                                           std::numeric_limits<double>::min());
+        }
 
       // At this point we have the pair.
 
-      // qDebug() << "pair:" << range_pair;
+      qDebug() << "pair:" << range_pair;
 
       return range_pair;
     }
@@ -627,7 +635,7 @@ MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
       // qDebug() << "text that matched:" << text;
 
       // By essence the upper value is max.
-      range_pair.second = std::numeric_limits<std::size_t>::max();
+      range_pair.second = std::numeric_limits<double>::max();
 
       // Get the string value.
       QString lower_value_string = match.captured(1);
@@ -779,7 +787,7 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
       if(m_dtValuesPair.first == std::numeric_limits<double>::max() ||
          m_dtValuesPair.second == std::numeric_limits<double>::min())
         {
-          // qDebug();
+          qDebug();
           return false;
         }
     }
@@ -857,52 +865,6 @@ MsRunDataSetTableViewProxyModel::setPrecision(pappso::PrecisionPtr precision_p)
 }
 
 
-bool
-MsRunDataSetTableViewProxyModel::fillInProcessingFlow(
-  ProcessingFlow &processing_flow)
-{
-  bool was_correctly_filled_in = false;
-
-  MsFragmentationSpec ms_fragmentation_spec;
-
-  if(m_msLevel)
-    ms_fragmentation_spec.setMsLevel(m_msLevel);
-
-  if(ms_fragmentation_spec.isValid())
-    {
-      processing_flow.setDefaultMsFragmentationSpec(ms_fragmentation_spec);
-      was_correctly_filled_in = true;
-    }
-
-  ProcessingStep *new_processing_step_p = new ProcessingStep;
-
-  if(isValidFilterPair(m_rtValuesPair))
-    {
-      ProcessingSpec *new_processing_spec_p =
-        new ProcessingSpec(m_rtValuesPair.first, m_rtValuesPair.second);
-
-      new_processing_step_p->newSpec("RT_TO_ANY", new_processing_spec_p);
-      was_correctly_filled_in = true;
-    }
-
-  if(isValidFilterPair(m_dtValuesPair))
-    {
-      ProcessingSpec *new_processing_spec_p =
-        new ProcessingSpec(m_dtValuesPair.first, m_dtValuesPair.second);
-
-      new_processing_step_p->newSpec("DT_TO_ANY", new_processing_spec_p);
-      was_correctly_filled_in = true;
-    }
-
-  if(was_correctly_filled_in)
-    processing_flow.push_back(new_processing_step_p);
-  else
-    delete new_processing_step_p;
-
-  return was_correctly_filled_in;
-}
-
-
 bool
 MsRunDataSetTableViewProxyModel::isValidFilterPair(
   const std::pair<std::size_t, std::size_t> &pair) const
@@ -1102,8 +1064,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
           // If sep ';' does not match anywhere in the string, split() returns a
           // single-element list containing this string.
 
-          QStringList mz_value_string_list(
-            data.split(';', Qt::SkipEmptyParts));
+          QStringList mz_value_string_list(data.split(';', Qt::SkipEmptyParts));
 
           if(!mz_value_string_list.isEmpty())
             {
