@@ -372,7 +372,9 @@ MsRunDataSetTableViewWnd::executeFilteringPushButtonClicked()
 void
 MsRunDataSetTableViewWnd::showMzIntegrationParamsDlg()
 {
-  // qDebug();
+
+  qDebug() << "Showing mz integration params for values:"
+           << m_processingFlow.getDefaultMzIntegrationParams().toString();
 
   if(mp_mzIntegrationParamsDlg == nullptr)
     {
@@ -402,8 +404,8 @@ void
 MsRunDataSetTableViewWnd::mzIntegrationParamsChanged(
   pappso::MzIntegrationParams mz_integration_params)
 {
-  // qDebug().noquote() << "The validated mz integration parameters:"
-  //<< mz_integration_params.toString();
+  qDebug().noquote() << "The validated mz integration parameters:"
+                     << mz_integration_params.toString();
 
   // We cannot copy the params returned as parameter into the destination
   // because we would loose the greatestMz/smallesMz values that we got from the
@@ -427,8 +429,8 @@ MsRunDataSetTableViewWnd::mzIntegrationParamsChanged(
 
   m_processingFlow.setDefaultMzIntegrationParams(local_mz_integration_params);
 
-  // qDebug() << "Set new mz integ params to m_processingFlow:"
-  //<< local_mz_integration_params.toString();
+  qDebug() << "Set new mz integ params to m_processingFlow:"
+           << m_processingFlow.getDefaultMzIntegrationParams().toString();
 }
 
 
@@ -738,7 +740,7 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
 void
 MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 {
-  qDebug() << "Integration type:" << integration_type;
+  //qDebug() << "Integration type:" << integration_type;
 
   // We need to craft a brand new processing flow because we do not want to
   // pollute the member datum.
@@ -759,6 +761,9 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   step_p->setMzIntegrationParams(
     local_processing_flow.getDefaultMzIntegrationParams());
 
+  //qDebug() << "At integration time, mz integration params"
+           //<< local_processing_flow.getDefaultMzIntegrationParams().toString();
+
   // At this point, make sure we document in the processing flow the other
   // critical parameters: the RT and DT values along with the MS fragmentation
   // spec data. These elements are not taken into the account in the integration
@@ -778,8 +783,8 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
   if(!vector_of_qualified_mass_spectra.size())
     return;
 
-  qDebug() << "The number of spectra recorded for integration:"
-           << vector_of_qualified_mass_spectra.size();
+  //qDebug() << "The number of spectra recorded for integration:"
+           //<< vector_of_qualified_mass_spectra.size();
 
   // We have finished documenting the flow's step, append it to the processing
   // flow.
