@@ -55,7 +55,6 @@
 #include "OpenMsRunDataSetsDlg.hpp"
 
 #include "../nongui/MassDataIntegrator.hpp"
-#include "../nongui/MassDataIntegratorTask.hpp"
 
 #include "TaskMonitorWnd.hpp"
 
@@ -82,7 +81,6 @@
 #include "../nongui/AnalysisPreferences.hpp"
 #include "AnalysisPreferencesDlg.hpp"
 
-
 // All the integrators that are based on the use of Qualified Mass Spectrum
 // Vector Visitors.
 
@@ -120,6 +118,9 @@ class ProgramWindow : public QMainWindow
 
   friend class OpenMsRunDataSetsDlg;
 
+  ////////////////////////////// public //////////////////////////// /
+  ////////////////////////////// public //////////////////////////////
+
   public:
   explicit ProgramWindow(QWidget *parent, const QString &module_name);
   virtual ~ProgramWindow();
@@ -129,12 +130,17 @@ class ProgramWindow : public QMainWindow
   void setMaxThreadUseCount(std::size_t count);
   std::size_t getMaxThreadUseCount();
 
-  bool openMassSpectrometryFileDlg(const QString &dir_name = QDir::homePath(),
-                                   bool full_in_memory     = false);
-  bool openMassSpectrometryFile(const QString &fileName    = QString(),
-                                bool full_in_memory        = false,
-                                const QString &sample_name = QString());
+  Q_INVOKABLE bool
+  openMassSpectrometryFileDlg(const QString &dir_name = QDir::homePath(),
+                              bool full_in_memory     = false);
+
+  Q_INVOKABLE bool
+  openMassSpectrometryFile(const QString &fileName    = QString(),
+                           bool full_in_memory        = false,
+                           const QString &sample_name = QString());
+
   bool openMassSpectrometryFileFromClipBoard();
+
   bool openMassSpectrometryFileFromText(const QString &text,
                                         const QString &sample_name);
 
@@ -222,6 +228,9 @@ class ProgramWindow : public QMainWindow
   void plotCompositeWidgetDestructionRequested(
     BasePlotCompositeWidget *base_plot_composite_widget_p);
 
+  ///////////////////////////// public slots /////////////////////////////
+  ///////////////////////////// public slots /////////////////////////////
+
   public slots:
 
   void finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp);
@@ -244,6 +253,9 @@ class ProgramWindow : public QMainWindow
 
   void recordAnalysisStanza(QString stanza, const QColor &color = Qt::black);
 
+  ///////////////////////////// signals /////////////////////////////
+  ///////////////////////////// signals /////////////////////////////
+
   signals:
 
   void readMsRunDataSignal(MsRunReadTask *ms_run_read_task_p,
@@ -281,6 +293,8 @@ class ProgramWindow : public QMainWindow
 
   void cancelOperationSignal();
 
+  /////////////////////////////  protected  /////////////////////////////
+  /////////////////////////////  protected  /////////////////////////////
   protected:
   //! The name of the module, at the moment massXpert or mineXpert.
   QString m_moduleName = "mineXpert2";
@@ -368,7 +382,7 @@ class ProgramWindow : public QMainWindow
 
   void showTicXicChromatogramsWnd();
   void showMassSpectraWnd();
-  void showDriftSpectraWnd();
+  Q_INVOKABLE void showDriftSpectraWnd();
 
   void showXicExtractionWnd();
 
@@ -386,7 +400,7 @@ class ProgramWindow : public QMainWindow
                                     const QColor &color);
 
   void showMassPeakShaperDlg();
-  void showIsoSpecDlg();
+  Q_INVOKABLE void showIsoSpecDlg();
 
   void cancelOperationPushButtonClicked();
 
