@@ -233,7 +233,7 @@ SaveToGraphicsFileDlg::okPushButton()
   int height = m_ui.heightSpinBox->value();
   int scale  = m_ui.scaleSpinBox->value();
 
-  if(format != GraphicsFormat::GRAPHICS_FORMAT_PDF ||
+  if(format != GraphicsFormat::GRAPHICS_FORMAT_PDF &&
      format != GraphicsFormat::GRAPHICS_FORMAT_SVG)
     {
       if(scale == 0)
