@@ -192,16 +192,20 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(!context.m_selectionPolygon.is2D())
     {
-      qDebug() << "The selection polygon cannot be mono-dimensional when "
-                  "selecting for integration from color map";
+      // qDebug() << "The selection polygon cannot be mono-dimensional when "
+      //"selecting for integration from color map";
       return;
     }
   else
     {
       if(context.m_selectionPolygon.isRectangle())
-        qDebug() << "The selection polygon is rectangle.";
+        {
+          // qDebug() << "The selection polygon is rectangle.";
+        }
       else
-        qDebug() << "The selection polygon is oblique (skewed).";
+        {
+          // qDebug() << "The selection polygon is oblique (skewed).";
+        }
     }
 
   // Sanity check.
@@ -215,7 +219,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
 
-  //qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
+  // qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
   if(x_range_start < 0 && x_range_end < 0)
     return;
@@ -225,7 +229,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
 
-  //qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
+  // qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
   if(y_range_start < 0 && y_range_end < 0)
     return;
@@ -317,9 +321,13 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       ->yAxisDataKind();
 
   if(x_axis_data_kind == pappso::DataKind::mz)
-    qDebug() << "X axis: mz";
+    {
+      // qDebug() << "X axis: mz";
+    }
   else if(x_axis_data_kind == pappso::DataKind::rt)
-    qDebug() << "X axis: rt";
+    {
+      // qDebug() << "X axis: rt";
+    }
 
   if(x_axis_data_kind == pappso::DataKind::mz &&
      y_axis_data_kind != pappso::DataKind::rt)
@@ -345,13 +353,13 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(x_axis_data_kind == pappso::DataKind::rt)
     {
-        // We have to transpose the selection rectangle so that x:DT and y:RT.
+      // We have to transpose the selection rectangle so that x:DT and y:RT.
       local_selection_polygon = local_selection_polygon.transpose();
     }
   // else
   // No need to tranpose, we deal with data in the right x:MZ y:RT.
 
-   qDebug() << "The selection polygon:" << local_selection_polygon.toString();
+  // qDebug() << "The selection polygon:" << local_selection_polygon.toString();
 
   // Now we know we have the right selection polygon for x:MZ and y:RT.
 
@@ -372,7 +380,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   if(m_ui.integrateToRtPushButton->isChecked())
     {
-       qDebug() << "Integrating to XIC chromatogram.";
+      // qDebug() << "Integrating to XIC chromatogram.";
 
       processing_step_p->setDestProcessingType("RT");
 
@@ -383,7 +391,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtRtPushButton->isChecked())
     {
-       qDebug() << "Integrating to dt / rt color map.";
+      // qDebug() << "Integrating to dt / rt color map.";
 
       processing_step_p->setDestProcessingType("DT_RT");
 
@@ -399,19 +407,19 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       if(m_ui.integrateToMzPushButton->isChecked())
         {
-           qDebug() << "Integrating to mass spectrum.";
+          // qDebug() << "Integrating to mass spectrum.";
 
           processing_step_p->setDestProcessingType("MZ");
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
-           qDebug() << "Integrating to m/z / rt color map.";
+          // qDebug() << "Integrating to m/z / rt color map.";
 
           processing_step_p->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
-           qDebug() << "Integrating to dt / m/z color map.";
+          // qDebug() << "Integrating to dt / m/z color map.";
 
           processing_step_p->setDestProcessingType("DT_MZ");
         }
@@ -427,12 +435,18 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
+      // qDebug()
+      //<< "The graph's processing flow has default mz integration params:"
+      //<< mz_integration_params.toString();
+
       // If it is not valid, then try mz integration params from the various
       // steps of the flow. Preferentially the most recent ones.
       if(!mz_integration_params.isValid())
         {
           // qDebug()
-          //<< "The processing flow's default mz integ params are not valid.";
+          //<< "The processing flow's default mz integ params are not "
+          //"valid. Trying to get the most recent mz integ params "
+          //"from the processing flow. If valid, we may tune them later.";
 
           mz_integration_params =
             *(local_processing_flow.mostRecentMzIntegrationParams());
@@ -443,16 +457,60 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // while it was loaded from file.
       if(!mz_integration_params.isValid())
         {
-          // qDebug() << "The most recent mz integ param are not valid.";
+          //qDebug() << "The most recent mz integ param are not valid. We use "
+                      //"the getMsRunDataSetStats to craft new ones that we may "
+                      //"tune later.";
 
           mz_integration_params =
             ms_run_data_set_csp->craftInitialMzIntegrationParams();
         }
+      else
+        {
+          //qDebug() << "The most recent mz integ params are valid. Use them, "
+                      //"with potential tuning.";
+        }
 
       if(!mz_integration_params.isValid())
         qFatal(
           "The mz integ params from the ms run data set stats are not valid.");
 
+      // At this point, let's see if we can optimize the integration
+      // computation. Indeed, if we know we have an mz range in the selection
+      // polygon, document that range to lower computing time.
+
+      double mz_range_lower = std::numeric_limits<double>::max();
+      double mz_range_upper = std::numeric_limits<double>::min();
+
+      // We know we have the x axis being the dt while the mz is the y axis.
+
+      bool res = local_selection_polygon.rangeY(mz_range_lower, mz_range_upper);
+
+      if(!res)
+        {
+          qFatal("Failed to get the m/z range out of the selection polygon");
+        }
+
+      // At this point, change the values in the mz_integration_params so
+      // that the min and max values match the range, which will ensure that
+      // the integration is the quickest possible as the bins are created in
+      // this range and not in another one that might be larger (if the
+      // integration comes right from the intial TIC, then the range is the
+      // whole range of the mass data in the dataset.
+
+      mz_integration_params.setSmallestMz(mz_range_lower);
+      mz_integration_params.setGreatestMz(mz_range_upper);
+
+      //qDebug() << "After tuning the mz range, mz integration params:"
+               //<< mz_integration_params.toString();
+
+
+#if 0
+
+      // This is no more true: we do not force a low resolution computation for
+      // the color maps. The mz integration parameters are now entirely
+      // satisfied.
+
+
       // Note that we cannot integrate mass spectra with a high resolution
       // here. We need to reduce the resolution to integer resolution.
       if(m_ui.integrateToDtMzPushButton->isChecked() ||
@@ -462,6 +520,8 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
           mz_integration_params.setDecimalPlaces(0);
         }
 
+#endif
+
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
       processing_step_p->setMzIntegrationParams(mz_integration_params);
@@ -495,7 +555,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtPushButton->isChecked())
     {
-      qDebug() << "Integrating to drift spectrum.";
+      //qDebug() << "Integrating to drift spectrum.";
 
       processing_step_p->setDestProcessingType("DT");
 
@@ -506,7 +566,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToIntPushButton->isChecked())
     {
-      qDebug() << "Integrating to TIC intensity.";
+      //qDebug() << "Integrating to TIC intensity.";
 
       processing_step_p->setDestProcessingType("INT");
 
