@@ -400,20 +400,20 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     {
       if(m_ui.integrateToMzPushButton->isChecked())
         {
-          qDebug() << "Integrating to mass spectrum.";
+          //qDebug() << "Integrating to mass spectrum.";
           processing_step_p->setDestProcessingType("MZ");
 
-          qDebug() << "Currently elaborating processing_step_p: "
-                   << processing_step_p->toString();
+          //qDebug() << "Currently elaborating processing_step_p: "
+                   //<< processing_step_p->toString();
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
-          qDebug() << "Integrating to rt|m/z color map.";
+          //qDebug() << "Integrating to rt|m/z color map.";
           processing_step_p->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
-          qDebug() << "Integrating to dt|m/z color map.";
+          //qDebug() << "Integrating to dt|m/z color map.";
           processing_step_p->setDestProcessingType("DT_MZ");
         }
 
@@ -498,7 +498,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtPushButton->isChecked())
     {
-      qDebug() << "Integrating to drift spectrum.";
+      //qDebug() << "Integrating to drift spectrum.";
 
       processing_step_p->setDestProcessingType("DT");
 
@@ -509,7 +509,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtRtPushButton->isChecked())
     {
-      qDebug() << "Integrating to dt/rt colormap.";
+      //qDebug() << "Integrating to dt/rt colormap.";
 
       processing_step_p->setDestProcessingType("DT_RT");
 
@@ -520,7 +520,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToIntPushButton->isChecked())
     {
-      qDebug() << "Integrating to TIC intensity.";
+      //qDebug() << "Integrating to TIC intensity.";
 
       processing_step_p->setDestProcessingType("INT");
 
