@@ -44,6 +44,7 @@
 
 
 /////////////////////// Local includes
+#include "Application.hpp"
 #include "ProgramWindow.hpp"
 #include "TicXicChromTracePlotWnd.hpp"
 #include "TicXicChromTracePlotCompositeWidget.hpp"
@@ -57,6 +58,7 @@ namespace msxps
 namespace minexpert
 {
 
+int TicXicChromTracePlotWnd::widgetCount = 0;
 
 //! Construct an TicXicChromTracePlotWnd instance.
 TicXicChromTracePlotWnd::TicXicChromTracePlotWnd(QWidget *parent,
@@ -91,8 +93,10 @@ TicXicChromTracePlotWnd::addTracePlot(
     new TicXicChromTracePlotCompositeWidget(
       this, "retention time (min)", "counts (a.u.)");
 
-  return finalNewTracePlotConfiguration(
+  QCPGraph *new_graph_p = finalNewTracePlotConfiguration(
     composite_widget_p, trace, processing_flow, color, parent_plottable_p);
+
+  return new_graph_p;
 }
 
 
