@@ -119,6 +119,8 @@ class TicXicChromTracePlotWnd : public BaseTracePlotWnd
     QualifiedMassSpectrumVectorMassDataIntegratorToRt *mass_data_integrator_p);
 
   protected:
+  // Counts statically the number of widgets in the window.
+  static int widgetCount;
 };
 
 
