@@ -160,8 +160,8 @@ XicExtractionWnd::runPushButtonClicked()
 
   double delta = mp_precision->delta(mz);
 
-  double mzStart = mz - delta;
-  double mzEnd   = mz + delta;
+  double mz_start = mz - delta;
+  double mz_end   = mz + delta;
 
   // At this point, get the list of all the mass data files that have their
   // item selected in the OpenSpectraDlg window.
@@ -179,25 +179,47 @@ XicExtractionWnd::runPushButtonClicked()
       return;
     }
 
+  // Craft a 2D selection polygon that will be used to specify the RT and MZ
+  // ranges.
+
+  pappso::SelectionPolygon selection_polygon;
+
   for(auto &&ms_run_data_set_csp : vector_of_ms_run_data_set_csp)
     {
       ProcessingFlow processing_flow(ms_run_data_set_csp);
 
-      ProcessingStep *processing_step_p = new ProcessingStep;
+      ProcessingStep *processing_step_p = new ProcessingStep();
 
-      ProcessingSpec *processing_spec_p = new ProcessingSpec(mzStart, mzEnd);
+      processing_step_p->setSrcProcessingType(pappso::Axis::x, "RT");
+      processing_step_p->setSrcProcessingType(pappso::Axis::y, "DATA_XIC_MZ");
 
-      processing_step_p->newSpec("MZ_TO_ANY", processing_spec_p);
+      processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
+      processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
+
+      double rt_start = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+                          ->getRootNodes()
+                          .front()
+                          ->getQualifiedMassSpectrum()
+                          ->getRtInMinutes();
+      double rt_end = ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
+                        ->getRootNodes()
+                        .back()
+                        ->getQualifiedMassSpectrum()
+                        ->getRtInMinutes();
+
+      // Craft the selection polygon as a 2D rectangle with x:RT and y:MZ.
+      selection_polygon.set2D(QPointF(rt_start, mz_end),
+                              QPointF(rt_end, mz_end),
+                              QPointF(rt_end, mz_start),
+                              QPointF(rt_start, mz_start));
+
+      processing_step_p->setDestProcessingType("RT");
+
+      processing_step_p->setSelectionPolygon(selection_polygon);
 
       processing_flow.push_back(processing_step_p);
 
-      processing_spec_p = new ProcessingSpec();
-
-      processing_step_p->newSpec("DATA_TO_RT", processing_spec_p);
-
-      processing_flow.push_back(processing_step_p);
-
-      mp_programWindow->xicIntegrationToRt(processing_flow);
+      mp_programWindow->integrateToRt(nullptr, nullptr, processing_flow);
     }
 
   return;
