@@ -152,6 +152,10 @@ main(int argc, char **argv)
     new msxps::minexpert::ProgramWindow(nullptr, "mineXpert2");
   main_window_p->show();
 
+  // Store the program window pointer to the Application instance so that we can
+  // systematically find it there for the JavaScript'ing stuff.
+  application.setProgramWindow(main_window_p);
+
   const QStringList args = parser.positionalArguments();
 
   if(!args.isEmpty())
