@@ -101,13 +101,13 @@ class Atom : public Ponderable
   Atom(const Atom &other);
   virtual ~Atom();
 
-  Atom *clone() const;
+  virtual Atom *clone() const;
 
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Woverloaded-virtual"
-  void clone(Atom *) const;
-  void mold(const Atom &);
-#pragma clang diagnostic pop
+  using Ponderable::clone;
+  virtual void clone(Atom *) const;
+
+  using Ponderable::mold;
+  virtual void mold(const Atom &);
 
   virtual Atom &operator=(const Atom &);
 
