@@ -67,9 +67,14 @@ class AtomCount : public Atom
   AtomCount();
   AtomCount(const AtomCount &);
 
-  AtomCount *clone() const;
-  void clone(AtomCount *) const;
-  void mold(const AtomCount &);
+  virtual AtomCount *clone() const override;
+
+  using Atom::clone;
+  virtual void clone(AtomCount *) const;
+
+  using Atom::mold;
+  virtual void mold(const AtomCount &);
+
   AtomCount &operator=(const AtomCount &);
 
   void setCount(int);
