@@ -34,6 +34,7 @@
 /////////////////////// Qt includes
 #include <QChar>
 #include <QString>
+#include <QRegularExpression>
 
 
 /////////////////////// Local includes
@@ -444,7 +445,7 @@ Formula::actions() const
   double quotes, that is located in front of the actual chemical
   actionformula.  This function removes that <em>title</em> element from the
   \c m_formula actionformula. The \e title substring of the actionformula is
-  removed using a QRegExp.
+  removed using a QRegularExpression.
 
   \return the number of removed characters.
 
@@ -454,7 +455,7 @@ Formula::removeTitle()
 {
   int length = m_formula.length();
 
-  m_formula.remove(QRegExp("\".*\""));
+  m_formula.remove(QRegularExpression("\".*\""));
 
   return (length - m_formula.length());
 }
@@ -465,7 +466,7 @@ Formula::removeTitle()
 
   Spaces can be placed anywhere in formula for more readability. However, it
   might be required that these character spaces be removed. This function does
-  just this, using a QRegExp.
+  just this, using a QRegularExpression.
 
   \return the number of removed characters.
 
@@ -477,7 +478,7 @@ Formula::removeSpaces()
 
   // We want to remove all the possibly-existing spaces.
 
-  m_formula.remove(QRegExp("\\s+"));
+  m_formula.remove(QRegularExpression("\\s+"));
 
   // Return the number of removed characters.
   return (length - m_formula.length());
@@ -562,11 +563,11 @@ Formula::splitParts(const QList<Atom *> &refList,
   // The "Decomposed adenine" is the title
   // The C5H4N5 +H is the formula.
 
-  formula.remove(QRegExp("\".*\""));
+  formula.remove(QRegularExpression("\".*\""));
 
   // We want to remove all the possibly-existing spaces.
 
-  formula.remove(QRegExp("\\s+"));
+  formula.remove(QRegularExpression("\\s+"));
 
   // If the formula does not contain any '-' character, then we
   // can approximate that all the formula is a '+' formula, that is a
@@ -1157,11 +1158,11 @@ Formula::checkSyntax(const QString &formula, bool forceCountIndex)
   // The "Decomposed adenine" is the title
   // The C5H4N5 +H is the formula.
 
-  localFormula.remove(QRegExp("\".*\""));
+  localFormula.remove(QRegularExpression("\".*\""));
 
   // We want to remove all the possibly-existing spaces.
 
-  localFormula.remove(QRegExp("\\s+"));
+  localFormula.remove(QRegularExpression("\\s+"));
 
 
   for(int iter = 0; iter < localFormula.length(); ++iter)
@@ -1569,7 +1570,7 @@ Formula::elementalComposition(
   QString positiveComponentString;
 
   // Carbon
-  atomIndex = positiveStringList.indexOf(QRegExp("C\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("C\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1581,7 +1582,7 @@ Formula::elementalComposition(
     }
 
   // Hydrogen
-  atomIndex = positiveStringList.indexOf(QRegExp("H\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("H\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1593,7 +1594,7 @@ Formula::elementalComposition(
     }
 
   // Nitrogen
-  atomIndex = positiveStringList.indexOf(QRegExp("N\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("N\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1605,7 +1606,7 @@ Formula::elementalComposition(
     }
 
   // Oxygen
-  atomIndex = positiveStringList.indexOf(QRegExp("O\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("O\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1617,7 +1618,7 @@ Formula::elementalComposition(
     }
 
   // Sulfur
-  atomIndex = positiveStringList.indexOf(QRegExp("S\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("S\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1629,7 +1630,7 @@ Formula::elementalComposition(
     }
 
   // Phosphorus
-  atomIndex = positiveStringList.indexOf(QRegExp("P\\d+"));
+  atomIndex = positiveStringList.indexOf(QRegularExpression("P\\d+"));
   if(atomIndex != -1)
     {
       positiveComponentString += positiveStringList.at(atomIndex);
@@ -1674,7 +1675,7 @@ Formula::elementalComposition(
   QString negativeComponentString;
 
   // Carbon
-  atomIndex = negativeStringList.indexOf(QRegExp("C\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("C\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1686,7 +1687,7 @@ Formula::elementalComposition(
     }
 
   // Hydrogen
-  atomIndex = negativeStringList.indexOf(QRegExp("H\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("H\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1698,7 +1699,7 @@ Formula::elementalComposition(
     }
 
   // Nitrogen
-  atomIndex = negativeStringList.indexOf(QRegExp("N\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("N\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1710,7 +1711,7 @@ Formula::elementalComposition(
     }
 
   // Oxygen
-  atomIndex = negativeStringList.indexOf(QRegExp("O\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("O\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1722,7 +1723,7 @@ Formula::elementalComposition(
     }
 
   // Sulfur
-  atomIndex = negativeStringList.indexOf(QRegExp("S\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("S\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
@@ -1734,7 +1735,7 @@ Formula::elementalComposition(
     }
 
   // Phosphorus
-  atomIndex = negativeStringList.indexOf(QRegExp("P\\d+"));
+  atomIndex = negativeStringList.indexOf(QRegularExpression("P\\d+"));
   if(atomIndex != -1)
     {
       negativeComponentString += negativeStringList.at(atomIndex);
