@@ -33,6 +33,7 @@
 
 /////////////////////// Qt includes
 #include <QString>
+#include <QDebug>
 
 /////////////////////// Local includes
 #include "IsoSpecEntity.hpp"
@@ -204,8 +205,35 @@ IsoSpecEntity::operator=(const IsoSpecEntity &other)
   return *this;
 }
 
+bool
+IsoSpecEntity::operator==(const IsoSpecEntity &other) const
+{
+  int errors = 0;
+
+  errors += (m_id == other.m_id ? 0 : 1);
+  errors += (m_element == other.m_element ? 0 : 1);
+  errors += (m_symbol == other.m_symbol ? 0 : 1);
+  errors += (m_atomicNo == other.m_atomicNo ? 0 : 1);
+  errors += (m_mass == other.m_mass ? 0 : 1);
+  errors += (m_massNo == other.m_massNo ? 0 : 1);
+  errors += (m_extraNeutrons == other.m_extraNeutrons ? 0 : 1);
+  errors += (m_probability == other.m_probability ? 0 : 1);
+  errors += (m_logProbability == other.m_logProbability ? 0 : 1);
+  errors += (m_radioactive == other.m_radioactive ? 0 : 1);
+
+  return (errors > 0 ? false : true);
+}
+
+
+bool
+IsoSpecEntity::operator!=(const IsoSpecEntity &other) const
+{
+  return !(*this == other);
+}
+
+
 QString
-IsoSpecEntity::asText()
+IsoSpecEntity::toString()
 {
   return QString("%1, %2, %3, %4, %5, %6, %7, %8, %9, %10")
     .arg(m_id)
