@@ -88,7 +88,7 @@ class IsoSpecEntity
                 int extraNeutrons,
                 double probability,
                 double logProbability,
-                bool radioactiveQString);
+                bool radioactive);
 
   IsoSpecEntity(const IsoSpecEntity &other);
   virtual ~IsoSpecEntity();
@@ -105,8 +105,10 @@ class IsoSpecEntity
   bool getRadioactive() const;
 
   virtual IsoSpecEntity &operator=(const IsoSpecEntity &other);
+  bool operator==(const IsoSpecEntity &other) const;
+  bool operator!=(const IsoSpecEntity &other) const;
 
-  QString asText();
+  QString toString();
 };
 
 } // namespace minexpert
