@@ -197,12 +197,17 @@ MassPeakShaper::computeGaussianPeakShape()
   double mz          = m_peakCentroid.x;
   double probability = m_peakCentroid.y;
 
-  // First off, we need to tell what the
-  double a = m_config.a(mz);
+  // First off, we need to tell what the height of the gaussian peak should be.
+  double a;
+  // a = m_config.a(mz);
 
-  // We set a to 1
+  // We actually set a to 1, because it is the probability above that will
+  // provide the height of the peak, see below where the heigh of the peak is
+  // set to a * probability, that is, probability if a = 1.
   a = 1;
 
+  //qDebug() << "a value:" << a;
+
   // The calls below will trigger the computation of fwhm in the config
   // instance, if it is equal to 0 because it was not set manually.
 
@@ -237,7 +242,7 @@ MassPeakShaper::computeGaussianPeakShape()
   //<< "\n\tcSquare:" << cSquare
   //<< "\n\titerations for calculation:" << iterations << "\n";
 
-  std::setprecision(10);
+  (void) std::setprecision(10);
 
   for(int iter = 0; iter < iterations; ++iter)
     {
@@ -273,10 +278,17 @@ MassPeakShaper::computeLorentzianPeakShape()
 
   double probability = m_peakCentroid.y;
 
-  double a = m_config.a(mz);
-  // We set a to 1
+  // First off, we need to tell what the height of the gaussian peak should be.
+  double a;
+  // a = m_config.a(mz);
+
+  // We actually set a to 1, because it is the probability above that will
+  // provide the height of the peak, see below where the heigh of the peak is
+  // set to a * probability, that is, probability if a = 1.
   a = 1;
 
+  //qDebug() << "a value:" << a;
+
   // The calls below will trigger the computation of fwhm, if it is
   // equal to 0 because it was not set manually.
   double gamma        = m_config.gamma(mz);
