@@ -69,7 +69,7 @@ typedef std::shared_ptr<const MsRunDataSet> MsRunDataSetCstSPtr;
 
 
 class MsRunDataSetStats;
-//class pappso::MzIntegrationParams;
+// class pappso::MzIntegrationParams;
 
 class MsRunDataSet : public QObject
 {
@@ -123,7 +123,8 @@ class MsRunDataSet : public QObject
   using Map =
     std::map<pappso::pappso_double, pappso::QualifiedMassSpectrumCstSPtr>;
 
-  pappso::QualifiedMassSpectrumCstSPtr massSpectrumAtIndex(std::size_t index) const;
+  pappso::QualifiedMassSpectrumCstSPtr
+  massSpectrumAtIndex(std::size_t index) const;
 
   int size() const;
 
@@ -163,6 +164,13 @@ class MsRunDataSet : public QObject
   // The ms run reader is required when the data are have been loaded in
   // streamed mode and thus the mass spectral data are not in memory, it is
   // necessary to access them from the file.
+
+  // FIXME: this is where we need to see if having more than one ms run reader
+  // is useful when loading data from Bruker timsTOF instruments. For the time
+  // being, simply create a specific reader for Bruker::timsTOF data that will
+  // combine all the scans of each frame and fill in the ms run data tree
+  // accordingly.
+
   pappso::MsRunReaderSPtr msp_msRunReader = nullptr;
 
   pappso::MzFormat m_fileFormat = pappso::MzFormat::unknown;
