@@ -694,8 +694,8 @@ MsRunDataSetStats::consolidate()
   m_greatestStepAvg    = average;
   m_greatestStepStdDev = stdDeviation;
 
-  QString text = toString();
-  qDebug().noquote() << text;
+  //QString text = toString();
+  //qDebug().noquote() << text;
 }
 
 
