@@ -35,6 +35,9 @@
 #include <iostream>
 #include <iomanip>
 #include <cmath>
+#include <chrono>
+#include <vector>
+#include <iterator>
 
 
 /////////////////////// OpenMP include
@@ -45,10 +48,12 @@
 #include <QThread>
 
 /////////////////////// pappsomspp includes
+#include <pappsomspp/trace/maptrace.h>
 #include <pappsomspp/processing/combiners/tracepluscombiner.h>
 
 
 /////////////////////// Local includes
+#include "MassDataIntegrator.hpp"
 #include "MsRunDataSetTreeMassDataIntegratorToRt.hpp"
 #include "ProcessingStep.hpp"
 #include "ProcessingType.hpp"
@@ -104,7 +109,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt(
 
 MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt(
   const MsRunDataSetTreeMassDataIntegratorToRt &other)
-  : MassDataIntegrator(other)
+  : MassDataIntegrator(other.mcsp_msRunDataSet, other.m_processingFlow)
 {
   // Essential that the m_processingFlow member is configured to have the right
   // pointer to the ms run data set.
@@ -335,8 +340,8 @@ MsRunDataSetTreeMassDataIntegratorToRt::
 
   // Now perform a parallel iteration in the various visitors and ask them to
   // work on the matching ms run data set iterators pair.
-   omp_set_num_threads(visitors.size());
-  #pragma omp parallel for ordered
+  omp_set_num_threads(visitors.size());
+#pragma omp parallel for ordered
   for(std::size_t iter = 0; iter < visitors.size(); ++iter)
     {
       auto multi_visitor_sp = visitors.at(iter);
@@ -350,12 +355,12 @@ MsRunDataSetTreeMassDataIntegratorToRt::
         iterators.at(iter).first,
         iterators.at(iter).second);
 
-      //qDebug() << "Finished running the visitor at index:" << iter
-               //<< "and the m_maxMz for the data stats is:"
-               //<< dynamic_cast<const MsRunStatisticsTreeNodeVisitor *>(
-                    //multi_visitor_sp->m_visitors.back().get())
-                    //->getMsRunDataSetStats()
-                    //.m_maxMz;
+      // qDebug() << "Finished running the visitor at index:" << iter
+      //<< "and the m_maxMz for the data stats is:"
+      //<< dynamic_cast<const MsRunStatisticsTreeNodeVisitor *>(
+      // multi_visitor_sp->m_visitors.back().get())
+      //->getMsRunDataSetStats()
+      //.m_maxMz;
     }
   // End of
   // #pragma omp parallel for
@@ -425,32 +430,32 @@ MsRunDataSetTreeMassDataIntegratorToRt::
 
       emit setProgressBarCurrentValueSignal(iter + 1);
 
-      //qDebug() << "Going to merge a visitor's MsRunDataSetStats and the "
-                  //"m_maxMz for the data stats is:"
-               //<< dynamic_cast<const MsRunStatisticsTreeNodeVisitor *>(
-                    //multi_visitor_sp->m_visitors.back().get())
-                    //->getMsRunDataSetStats()
-                    //.m_maxMz;
+      // qDebug() << "Going to merge a visitor's MsRunDataSetStats and the "
+      //"m_maxMz for the data stats is:"
+      //<< dynamic_cast<const MsRunStatisticsTreeNodeVisitor *>(
+      // multi_visitor_sp->m_visitors.back().get())
+      //->getMsRunDataSetStats()
+      //.m_maxMz;
 
-      //qDebug() << "We are merging one visitor's ms run data set stats:"
-               //<< stats_visitor_sp.get()->getMsRunDataSetStats().toString();
+      // qDebug() << "We are merging one visitor's ms run data set stats:"
+      //<< stats_visitor_sp.get()->getMsRunDataSetStats().toString();
 
-      //qDebug()
-        //<< "Before the merge, the ms_run_data_set_stats_merge has m_maxMz:"
-        //<< ms_run_data_set_stats_merge.m_maxMz;
+      // qDebug()
+      //<< "Before the merge, the ms_run_data_set_stats_merge has m_maxMz:"
+      //<< ms_run_data_set_stats_merge.m_maxMz;
 
       ms_run_data_set_stats_merge.merge(
         stats_visitor_sp.get()->getMsRunDataSetStats());
 
-      //qDebug()
-        //<< "After the merge, the ms_run_data_set_stats_merge has m_maxMz:"
-        //<< ms_run_data_set_stats_merge.m_maxMz;
+      // qDebug()
+      //<< "After the merge, the ms_run_data_set_stats_merge has m_maxMz:"
+      //<< ms_run_data_set_stats_merge.m_maxMz;
     }
 
   // At this point we finally have the statistical data merged into a single
   // instance. We now need to consolidate.
 
-  //qDebug() << "Final consolidation of the statistics.";
+  // qDebug() << "Final consolidation of the statistics.";
 
   ms_run_data_set_stats_merge.consolidate();
 
@@ -463,7 +468,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   std::const_pointer_cast<MsRunDataSet>(mcsp_msRunDataSet)
     ->setMsRunDataSetStats(ms_run_data_set_stats_merge);
 
-  // qDebug().noquote() << mcsp_msRunDataSet->getMsRunDataSetStats().toString();
+  //qDebug().noquote() << mcsp_msRunDataSet->getMsRunDataSetStats().toString();
 
   std::chrono::system_clock::time_point chrono_end_time =
     std::chrono::system_clock::now();
