@@ -135,17 +135,22 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
   MsRunDataSetCstSPtr mcsp_msRunDataSet = nullptr;
 
   ProcessingFlow m_processingFlow;
-  
+
   std::size_t m_maxThreadUseCount = 0;
 
-  std::pair<double, double> m_rtRange = std::pair<double, double>(
-    std::numeric_limits<double>::max(), std::numeric_limits<double>::min());
+  std::vector<ProcessingStep> m_innermostSteps2D;
 
-  std::pair<double, double> m_dtRange = std::pair<double, double>(
-    std::numeric_limits<double>::max(), std::numeric_limits<double>::min());
+  std::vector<pappso::SelectionPolygonSpec> m_selectionPolygonSpecs;
 
-  std::pair<double, double> m_mzRange = std::pair<double, double>(
-    std::numeric_limits<double>::max(), std::numeric_limits<double>::min());
+  std::pair<double, double> m_dtRange =
+    std::pair<double, double>(std::numeric_limits<double>::quiet_NaN(),
+                              std::numeric_limits<double>::quiet_NaN());
+  std::pair<double, double> m_mzRange =
+    std::pair<double, double>(std::numeric_limits<double>::quiet_NaN(),
+                              std::numeric_limits<double>::quiet_NaN());
+  std::pair<double, double> m_rtRange =
+    std::pair<double, double>(std::numeric_limits<double>::quiet_NaN(),
+                              std::numeric_limits<double>::quiet_NaN());
 
   const QualifiedMassSpectraVectorSPtr
     mcsp_qualifiedMassSpectraToIntegrateVector;
@@ -163,9 +168,16 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
 
   virtual void setInnermostRanges();
 
+  virtual std::size_t fillInSelectionPolygonSpecs(
+    std::vector<pappso::SelectionPolygonSpec> &selection_polygon_specs);
+
   virtual bool checkMsLevel(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
 
+  virtual bool checkMsFragmentation(
+    const ProcessingStep &processing_step,
+    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
+
   virtual bool checkMsFragmentation(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
 
@@ -175,47 +187,13 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
   virtual bool checkDtRange(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
 
-  virtual bool checkProcessingStep(
-    const ProcessingStep &step,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
-
-  virtual bool checkProcessingStep(
-    const ProcessingStep &step,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp,
-    pappso::MassDataCombinerInterface &mass_spectrum_combiner);
-
-  virtual bool checkProcessingSpec(
-    const std::pair<ProcessingType, ProcessingSpec *> &type_spec_pair,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
-
-  virtual bool checkProcessingSpec(
-    const std::pair<ProcessingType, ProcessingSpec *> &type_spec_pair,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp,
-    pappso::MassDataCombinerInterface &mass_spectrum_combiner);
-
-  virtual bool checkProcessingTypeByRt(
-    const std::pair<ProcessingType, ProcessingSpec *> &spec_type_pair,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
-
-  virtual bool checkProcessingTypeByMz(
-    const std::pair<ProcessingType, ProcessingSpec *> &spec_type_pair,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
-
-  virtual bool checkProcessingTypeByMz(
-    const std::pair<ProcessingType, ProcessingSpec *> &spec_type_pair,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp,
-    pappso::MassDataCombinerInterface &mass_spectrum_combiner);
-
-  virtual bool checkProcessingTypeByDt(
-    const std::pair<ProcessingType, ProcessingSpec *> &spec_type_pair,
-    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
-
   protected:
   // We almost systematically need these m/z range values when making visits:
   // one criterium might be that the m/z value of data points (the x member of
   // DataPoint) be contained within the limit m/z range.
-  double m_limitMzRangeStart = std::numeric_limits<double>::max();
-  double m_limitMzRangeEnd   = std::numeric_limits<double>::max();
+  //
+  // Note that we set them to min() and max() because we'll use std::min() and
+  // std::max() against these values.
 
   using Iterator =
     std::vector<pappso::QualifiedMassSpectrumCstSPtr>::const_iterator;
@@ -229,6 +207,9 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
                          std::size_t thread_count,
                          int nodes_per_thread);
 
+  bool checkInnermostDtRt2DSteps(
+    pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
+
   private:
 };
 
