@@ -87,7 +87,7 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToDt
   public slots:
 
 
-  void integrateToDt();
+  void integrate();
   signals:
 
   protected:
