@@ -185,7 +185,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
 
   if(!mass_spectra_count)
     {
-      //qDebug() << "The qualified mass spectrum vector is empty, nothing to do.";
+      // qDebug() << "The qualified mass spectrum vector is empty, nothing to
+      // do.";
 
       emit cancelOperationSignal();
     }
@@ -303,16 +304,16 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
   // the ranges suffice, and they have been filled-in properly upon construction
   // of this integrator.
 
-  //qDebug() << "Now filling-in the selectionpolygonspecs.";
+  // qDebug() << "Now filling-in the selectionpolygonspecs.";
 
   std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
 
-  //std::size_t selection_polygon_spec_count =
-    fillInSelectionPolygonSpecs(selection_polygon_specs);
+  // std::size_t selection_polygon_spec_count =
+  fillInSelectionPolygonSpecs(selection_polygon_specs);
 
-  //qDebug() << selection_polygon_spec_count
-           //<< "selection polygon specs were retained for the configuration of "
-              //"the filter.";
+  // qDebug() << selection_polygon_spec_count
+  //<< "selection polygon specs were retained for the configuration of "
+  //"the filter.";
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
@@ -320,8 +321,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
   pappso::MzIntegrationParams local_mz_integration_params =
     m_processingFlow.getDefaultMzIntegrationParams();
 
-  //qDebug().noquote() << "Starting integration with mz integration params:"
-                     //<< local_mz_integration_params.toString();
+  // qDebug().noquote() << "Starting integration with mz integration params:"
+  //<< local_mz_integration_params.toString();
 
   // Instanciate a plus combiner that will be used as a template for all the
   // combiners operating concurrently below. Note that because we do not make
@@ -776,13 +777,17 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   // the ranges suffice, and they have been filled-in properly upon construction
   // of this integrator.
 
+  // We need this in some places, for debugging the bin creation and the mass
+  // spectrum combination.
+  //QString debug_string = "";
+
   // qDebug() << "Now filling-in the selectionpolygonspecs.";
 
   std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
 
-  //std::size_t selection_polygon_spec_count =
-    fillInSelectionPolygonSpecs(selection_polygon_specs);
-   //qDebug() << selection_polygon_spec_count
+  // std::size_t selection_polygon_spec_count =
+  fillInSelectionPolygonSpecs(selection_polygon_specs);
+  // qDebug() << selection_polygon_spec_count
   //<< "selection polygon specs were retained for the configuration of "
   //"the filter.";
 
@@ -826,7 +831,18 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   // Now we can create the bins!
   std::vector<double> bins = local_mz_integration_params.createBins();
 
-  //qDebug() << "Number of bins: " << bins.size();
+  //debug_string = QString(
+                   //"Number of bins: %1\n"
+                   //"First bins: %2 %3 %4 -- Last bins: %5 %6 %7\n")
+                   //.arg(bins.size())
+                   //.arg(bins[0], 0, 'f', 6)
+                   //.arg(bins[1], 0, 'f', 6)
+                   //.arg(bins[2], 0, 'f', 6)
+                   //.arg(bins[bins.size() - 3], 0, 'f', 6)
+                   //.arg(bins[bins.size() - 2], 0, 'f', 6)
+                   //.arg(bins[bins.size() - 1], 0, 'f', 6);
+
+  //qDebug().noquote() << debug_string;
 
   template_plus_combiner.setBins(bins);
 
@@ -911,10 +927,26 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
           if(m_isOperationCancelled)
             break;
 
-
           pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner(
             template_plus_combiner);
 
+          // std::vector<double> local_bins =
+          // mass_spectrum_plus_combiner.getBins();
+
+          // debug_string =
+          // QString(
+          //"Number of bins: %1\n"
+          //"First bins: %2 %3 %4 -- Last bins: %5 %6 %7\n")
+          //.arg(bins.size())
+          //.arg(bins[0], 0, 'f', 6)
+          //.arg(bins[1], 0, 'f', 6)
+          //.arg(bins[2], 0, 'f', 6)
+          //.arg(bins[bins.size() - 3], 0, 'f', 6)
+          //.arg(bins[bins.size() - 2], 0, 'f', 6)
+          //.arg(bins[bins.size() - 1], 0, 'f', 6);
+
+          // qDebug().noquote() << debug_string;
+
           // Make the computation.
 
           // For each mass spectrum all we need is compute its TIC value, that
@@ -983,22 +1015,18 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
           if(m_lastIntegrationDataKind == pappso::DataKind::rt)
             {
               first_key = rt_value;
+              //qDebug() << "The dt|rt key is actually a RT key with value:"
+                       //<< first_key;
             }
           else if(m_lastIntegrationDataKind == pappso::DataKind::dt)
             {
               first_key = dt_value;
+              //qDebug() << "The dt|rt key is actually a DT key with value:"
+                       //<< first_key;
             }
           else
             qFatal("Programming error.");
 
-          // We need to iterate in the current_map_trace_sp and find if there is
-          // already a map trace by the same dt|rt value in it.
-
-          Map::iterator double_maptrace_map_iterator;
-
-          double_maptrace_map_iterator =
-            current_double_maptrace_map_sp->find(first_key);
-
           // Before combining, we need to check if some filtering is
           // required as for m/z data.
 
@@ -1016,6 +1044,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
           if(!std::isnan(m_mzRange.first) && !std::isnan(m_mzRange.second))
             {
+              //qDebug() << "There appears to be an m/z-based filtering need.";
+
               pappso::FilterResampleKeepXRange the_keep_filter(
                 m_mzRange.first, m_mzRange.second);
 
@@ -1024,6 +1054,9 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
           if(selection_polygon_specs.size())
             {
+              //qDebug() << "There appears to be an selection polygon-based "
+                          //"filtering need.";
+
               pappso::FilterResampleKeepPointInPolygon the_polygon_filter(
                 selection_polygon_specs);
 
@@ -1035,15 +1068,23 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
           // At this point we can make the combination with the filtered trace.
 
+          // We need to iterate in the current_map_trace_sp and find if there is
+          // already a map trace by the same dt|rt value in it.
+
+          Map::iterator double_maptrace_map_iterator;
+
+          double_maptrace_map_iterator =
+            current_double_maptrace_map_sp->find(first_key);
+
           // Tells if the key was already found in the map.
           if(double_maptrace_map_iterator !=
              current_double_maptrace_map_sp->end())
             {
 
               // The map already contained a pair that had the key value ==
-              // first_key. All we have to do is combine the new mass
-              // spectrum pointed to by the map value into the MapTrace that is
-              // pointed to by the map key.
+              // first_key (remember, either dt or rt). All we have to do is
+              // combine the new mass spectrum pointed to by the map value into
+              // the MapTrace that is pointed to by the map key.
 
               // Combine the new mass spectrum right into the found MapTrace.
 
@@ -1052,6 +1093,20 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 
               mass_spectrum_plus_combiner.combine(
                 double_maptrace_map_iterator->second, filtered_trace);
+
+              //QString debug_string =
+                //QString(
+                  //"The current combination MapTrace's first element: (%1,%2)\n")
+                  //.arg(double_maptrace_map_iterator->second.begin()->first,
+                       //0,
+                       //'f',
+                       //6)
+                  //.arg(double_maptrace_map_iterator->second.begin()->second,
+                       //0,
+                       //'f',
+                       //6);
+
+              //qDebug().noquote() << debug_string;
             }
           else
             {
@@ -1064,13 +1119,44 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
               //<< first_key;
 
               // Instantiate a new MapTrace in which we'll combine this and all
-              // the future mass spectra having been acquired at this same dt
+              // the future mass spectra having been acquired at this same dt|rt
               // value.
 
               pappso::MapTrace map_trace;
 
+              // 20220812 See issue #6 at 
+              // https://gitlab.com/msxpertsuite/minexpert2/-/issues/6
+              // Where Kevin Hooijschuur explains that with
+              // multiplexed/demultiplexed mobility data from the Agilent 6560
+              // IMS-QTOF instrument, the color map that is computed is kind of
+              // blurred. 
+
+              // I discovered that the example file that Kevin provided me with,
+              // produced a final color map with a number of cells for the m/z
+              // dimension that did not match the number of bins. 
+              //
+              // I thus understood that that might be the problem and decided to
+              // force the final color map to have as many cells in the m/z
+              // dimension as there are bins by initializing each newly created
+              // map_trace with as many keys as there are bins all with 0-valued
+              // intensities.
+
+              for(double bin : bins)
+                map_trace[bin] = 0.0;
+
               mass_spectrum_plus_combiner.combine(map_trace, filtered_trace);
 
+              //QString debug_string =
+                //QString(
+                  //"The brand new rt|dt value: %1 combination MapTrace's first "
+                  //"element: "
+                  //"(%2,%3)\n")
+                  //.arg(first_key)
+                  //.arg(map_trace.begin()->first, 0, 'f', 6)
+                  //.arg(map_trace.begin()->second, 0, 'f', 6);
+
+              //qDebug().noquote() << debug_string;
+
               // Finally, store in the map, the map_trace along with its
               // first_key.
 
@@ -1124,6 +1210,21 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
       mass_spectrum_plus_combiner.setBins(bins);
     }
 
+  std::vector<double> local_bins = mass_spectrum_plus_combiner.getBins();
+
+  //debug_string = QString(
+                   //"Number of bins: %1\n"
+                   //"First bins: %2 %3 %4 -- Last bins: %5 %6 %7\n")
+                   //.arg(bins.size())
+                   //.arg(bins[0], 0, 'f', 6)
+                   //.arg(bins[1], 0, 'f', 6)
+                   //.arg(bins[2], 0, 'f', 6)
+                   //.arg(bins[bins.size() - 3], 0, 'f', 6)
+                   //.arg(bins[bins.size() - 2], 0, 'f', 6)
+                   //.arg(bins[bins.size() - 1], 0, 'f', 6);
+
+  //qDebug().noquote() << debug_string;
+
   int iter = 0;
 
   for(auto &&map_sp : vector_of_double_maptrace_maps)
@@ -1225,14 +1326,44 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
       return;
     }
 
+  // debug_string =
+  // QString(
+  //"For the first key (rt or dt) value (%1) of the double|maptrace map, "
+  //"this is the MapTrace content: %2\n")
+  //.arg(m_doubleMapTraceMapSPtr->begin()->first)
+  //.arg(m_doubleMapTraceMapSPtr->begin()->second.toString());
+
+  // qDebug().noquote() << debug_string;
+
+  //for(auto iter = m_doubleMapTraceMapSPtr->begin();
+      //iter != m_doubleMapTraceMapSPtr->end();
+      //++iter)
+    //{
+      //debug_string =
+        //QString(
+          //"For the last key (rt or dt) value (%1) of the double|maptrace map, "
+          //"this is the MapTrace content: %2\n\n")
+          //.arg(iter->first)
+          //.arg(iter->second.toString());
+
+      //qDebug().noquote() << debug_string;
+    //}
+
   m_colorMapMinKey = m_doubleMapTraceMapSPtr->begin()->first;
   m_colorMapMaxKey = m_doubleMapTraceMapSPtr->rbegin()->first;
 
   m_colorMapKeyCellCount = m_doubleMapTraceMapSPtr->size();
 
-  for(auto &&pair : *m_doubleMapTraceMapSPtr)
+  m_colorMapMzCellCount = std::numeric_limits<double>::min();
+
+  //qDebug() << "Initial data to configure the color map:"
+           //<< "m_colorMapMinKey: " << m_colorMapMinKey << "m_colorMapMaxKey"
+           //<< m_colorMapMaxKey << "m_colorMapKeyCellCount"
+           //<< m_colorMapKeyCellCount;
+
+  for(auto &&key_maptrace_pair : *m_doubleMapTraceMapSPtr)
     {
-      pappso::MapTrace map_trace = pair.second;
+      pappso::MapTrace map_trace = key_maptrace_pair.second;
 
       if(!map_trace.size())
         continue;
@@ -1247,6 +1378,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
         m_colorMapMaxMz = map_trace.rbegin()->first;
     }
 
+  //qDebug() << "At the end of the map data scrutinization, the following data "
+              //"have emerged"
+           //<< "m_colorMapMinMz:" << m_colorMapMinMz
+           //<< "m_colorMapMaxMz:" << m_colorMapMaxMz
+           //<< "m_colorMapMzCellCount:" << m_colorMapMzCellCount;
+
   return;
 }
 } // namespace minexpert
