@@ -100,7 +100,8 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz
   public slots:
 
   void integrate();
-
+  virtual void integrateNoBinning();
+  virtual void integrateArbitraryBinning();
 
   signals:
 
