@@ -87,7 +87,7 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToTicInt
 	
   public slots:
 
-  void integrateToTicIntensity();
+  void integrate();
 
   signals:
 
