@@ -41,7 +41,7 @@
 
 
 ////////////////////////////// Qt includes
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QFileInfo>
 #include <QDataStream>
 #include <QDebug>
@@ -245,7 +245,7 @@ unspacifyString(QString &text)
       return text;
     }
 
-  text.remove(QRegExp("\\s+"));
+  text.remove(QRegularExpression("\\s+"));
 
   return text;
 }
