@@ -81,6 +81,25 @@ enum MassType
 };
 
 
+//! Kind of entity handled in a JavaScript object creation operation.
+/*!
+ * When creating JavaScript objects, define which kind of entity is being
+ * created.
+ *
+ * \sa msXpSlibmassgui::ScriptingWnd
+ * \sa msXpSlibmassgui::ScriptingObjectTreeWidgetItem
+ */
+enum ScriptEntityType
+{
+  UndefinedEntity,
+  StringEntity,
+  FunctionEntity,
+  ArrayOrListEntity,
+  QObjectEntity,
+  IntegerEntity,
+  DoubleEntity
+};
+
 extern const double PI;
 
 extern int ATOM_DEC_PLACES;
